pub struct GeneratedSessionKeys {
pub keys: Bytes,
pub proof: Option<Bytes>,
}Expand description
Output of AuthorApiServer::rotate_keys_with_owner.
Fields
keys: BytesThe public session keys for registering them on chain.
proof: Option<Bytes>The proof for verifying ownership of the generated session keys.
This will be None iff the chain doesn’t support generating the proof.